scikit-cosmo documentation
===========================

``scikit-cosmo`` is a collection of `scikit-learn <https://scikit.org/>`_
compatible utilities that implement methods developed in the `COSMO laboratory
<https://cosmo.epfl.ch>`_.

.. toctree::
  :maxdepth: 1
  :caption: Contents:

  intro
  installation
  reference
  tutorials
  contributing
  bibliography
